@@ -13,18 +13,18 @@ Error_Code = {
 }
 
 
-def jsonify_success(data=None, msg=None):
-    return jsonify(True, 0, msg, data)
+def jsonify_success(data=None, msg=None, **kwargs):
+    return jsonify(True, 0, msg, data, **kwargs)
 
 
-def jsonify_fail(code=0, msg=None):
-    return jsonify(False, code, msg)
+def jsonify_fail(code=0, msg=None, **kwargs):
+    return jsonify(False, code, msg,**kwargs)
 
 
-def jsonify(success=False, code=0, msg=None, data=None):
+def jsonify(success=False, code=0, msg=None, data=None, **kwargs):
     if not msg:
         if success:
             msg = "成功"
         else:
             msg = Error_Code[code]
-    return jsonify_deity(success=success, code=code, msg=msg, data=data)
+    return jsonify_deity(success=success, code=code, msg=msg, data=data, **kwargs)
